==> freebsd-sys-8.2.tar.bz2: sys/sparc64/isa/isa_dma.c <==
/*-
 * Copyright (c) 2004 Pyun YongHyeon.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#include <sys/cdefs.h>
__FBSDID("$FreeBSD: src/sys/sparc64/isa/isa_dma.c,v 1.2.22.1.6.1 2010/12/21 17:09:25 kensmith Exp $");

#include <sys/param.h>
#include <sys/systm.h>
#include <sys/bus.h>

#include <isa/isareg.h>
#include <isa/isavar.h>

/*
 * Glue code to load sound(4). Though fdc(4), ppc(4) don't work on
 * sparc64 yet, they may need this glue code too.
 */

int
isa_dma_init(int chan, u_int bouncebufsize, int flag)
{

	return (0);
}

int
isa_dma_acquire(int chan)
{
	return (0);
}

void
isa_dma_release(int chan)
{

}

void
isa_dmacascade(int chan)
{

}

void
isa_dmastart(int flags, caddr_t addr, u_int nbytes, int chan)
{

}

void
isa_dmadone(int flags, caddr_t addr, int nbytes, int chan)
{

}

int
isa_dmastatus(int chan)
{
	return (0);
}

int
isa_dmatc(int chan)
{
	return (0);
}

int
isa_dmastop(int chan)
{
	return (0);
}

==> freebsd-sys-9.2_rc3.tar.bz2: sys/sparc64/isa/isa_dma.c <==
/*-
 * Copyright (c) 2004 Pyun YongHyeon.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#include <sys/cdefs.h>
__FBSDID("$FreeBSD: releng/9.2/sys/sparc64/isa/isa_dma.c 141391 2005-02-06 13:46:39Z phk $");

#include <sys/param.h>
#include <sys/systm.h>
#include <sys/bus.h>

#include <isa/isareg.h>
#include <isa/isavar.h>

/*
 * Glue code to load sound(4). Though fdc(4), ppc(4) don't work on
 * sparc64 yet, they may need this glue code too.
 */

int
isa_dma_init(int chan, u_int bouncebufsize, int flag)
{

	return (0);
}

int
isa_dma_acquire(int chan)
{
	return (0);
}

void
isa_dma_release(int chan)
{

}

void
isa_dmacascade(int chan)
{

}

void
isa_dmastart(int flags, caddr_t addr, u_int nbytes, int chan)
{

}

void
isa_dmadone(int flags, caddr_t addr, int nbytes, int chan)
{

}

int
isa_dmastatus(int chan)
{
	return (0);
}

int
isa_dmatc(int chan)
{
	return (0);
}

int
isa_dmastop(int chan)
{
	return (0);
}
